@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2021 Aleksandr Sizov <murkyrussian@gmail.com>
 #  Copyright 2021, 2022 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2021 Aleksandr Sizov <murkyrussian@gmail.com>
 #  This file is part of chython.
 #
 #  chython is free software; you can redistribute it and/or modify
@@ -30,8 +30,7 @@ class MorganFingerprint:
     __slots__ = ()
 
     def morgan_fingerprint(self, min_radius: int = 1, max_radius: int = 4,
-                           length: int = 1024, number_active_bits: int = 2,
-                           include_hydrogens: bool = True, with_pharmacophores: bool = False):
+                           length: int = 1024, number_active_bits: int = 2):
         """
         Transform structures into array of binary features.
         Morgan fingerprints. Similar to RDkit implementation.
@@ -40,20 +39,16 @@ class MorganFingerprint:
         :param max_radius: maximum radius of EC
         :param length: bit string's length. Should be power of 2
         :param number_active_bits: number of active bits for each hashed tuple
-        :param include_hydrogens: take into account hydrogen atoms
-        :param with_pharmacophores: use pharmacophoric features to identify and distinguish each atom in an molecule
 
         :return: array(n_features)
         """
-        bits = self.morgan_bit_set(min_radius, max_radius, length, number_active_bits, include_hydrogens,
-                                   with_pharmacophores)
+        bits = self.morgan_bit_set(min_radius, max_radius, length, number_active_bits)
         fingerprints = zeros(length, dtype=uint8)
         fingerprints[list(bits)] = 1
         return fingerprints
 
     def morgan_bit_set(self, min_radius: int = 1, max_radius: int = 4,
-                       length: int = 1024, number_active_bits: int = 2,
-                       include_hydrogens: bool = True, with_pharmacophores: bool = False) -> Set[int]:
+                       length: int = 1024, number_active_bits: int = 2) -> Set[int]:
         """
         Transform structures into set of indexes of True-valued features.
 
@@ -61,14 +56,12 @@ class MorganFingerprint:
         :param max_radius: maximum radius of EC
         :param length: bit string's length. Should be power of 2
         :param number_active_bits: number of active bits for each hashed tuple
-        :param include_hydrogens: take into account hydrogen atoms
-        :param with_pharmacophores: use pharmacophoric features to identify and distinguish each atom in an molecule
         """
         mask = length - 1
         log = int(log2(length))
 
         active_bits = set()
-        for tpl in self.morgan_hash_set(min_radius, max_radius, include_hydrogens, with_pharmacophores):
+        for tpl in self.morgan_hash_set(min_radius, max_radius):
             active_bits.add(tpl & mask)
             if number_active_bits == 2:
                 active_bits.add(tpl >> log & mask)
@@ -78,23 +71,15 @@ class MorganFingerprint:
                     active_bits.add(tpl & mask)
         return active_bits
 
-    def morgan_hash_set(self: 'MoleculeContainer', min_radius: int = 1, max_radius: int = 4,
-                        include_hydrogens: bool = True, with_pharmacophores: bool = False) -> Set[int]:
+    def morgan_hash_set(self: 'MoleculeContainer', min_radius: int = 1, max_radius: int = 4) -> Set[int]:
         """
         Transform structures into integer hashes of atoms with EC.
 
         :param min_radius: minimal radius of EC
         :param max_radius: maximum radius of EC
-        :param include_hydrogens: take into account hydrogen atoms
-        :param with_pharmacophores: use pharmacophoric features to identify and distinguish each atom in an molecule
         """
-        if with_pharmacophores:
-            identifiers = self.pharmacophores
-        elif include_hydrogens:
-            identifiers = {idx: hash(atom) for idx, atom in self.atoms()}
-        else:
-            identifiers = {idx: hash((atom.isotope or 0, atom.atomic_number, atom.charge, atom.is_radical))
-                           for idx, atom in self.atoms()}
+        identifiers = {idx: hash((atom.isotope or 0, atom.atomic_number, atom.charge, atom.is_radical))
+                       for idx, atom in self.atoms()}
 
         bonds = self._bonds
         arr = set()
