@@ -161,13 +161,13 @@ class Smiles(ABC):
         order = []
         visited_bond = set()
 
-        groups = defaultdict(int)
-        for n in atoms_set:
-            groups[weights(n)] -= 1
-
         if kwargs.get('random', False):
             mod_weights_start = mod_weights = weights
         else:
+            groups = defaultdict(int)
+            for n in atoms_set:
+                groups[weights(n)] -= 1
+
             def mod_weights_start(x):
                 return (groups[weights(x)],  # common groups
                         weights(x))  # smallest weight
@@ -179,13 +179,14 @@ class Smiles(ABC):
 
         while True:
             start = min(atoms_set, key=mod_weights_start)
-            seen[start] = 0
-            queue = [(start, 1)]
-            while queue:
-                n, d = queue.pop(0)
-                for m in bonds[n].keys() - seen.keys():
-                    queue.append((m, d + 1))
-                    seen[m] = d
+            if not kwargs.get('random', False):
+                seen[start] = 0
+                queue = [(start, 1)]
+                while queue:
+                    n, d = queue.pop(0)
+                    for m in bonds[n].keys() - seen.keys():
+                        queue.append((m, d + 1))
+                        seen[m] = d
 
             # modified NX dfs with cycle detection
             stack = [(start, len(atoms_set), iter(sorted(bonds[start], key=mod_weights)))]
@@ -309,6 +310,49 @@ class Smiles(ABC):
 class MoleculeSmiles(Smiles):
     __slots__ = ()
 
+    def sticky_smiles(self: Union['MoleculeContainer', 'MoleculeSmiles'], left: int, right: int = None, *,
+                      remove_left: bool = False, remove_right: bool = False, tries: int = 10):
+        """
+        Generate smiles with fixed left and optionally right terminal atoms.
+        Note: Produce expected results only with acyclic terminal atoms.
+
+        :param remove_left: drop terminal atom and corresponding bond
+        :param remove_right: drop terminal atom and corresponding bond
+        :param tries: number of attempts to generate smiles
+        """
+        bonds = self._bonds
+        bonds[left]  # noqa. check left atom availability
+        if right:
+            assert tries > 0, 'tries count should be positive'
+            assert len(bonds[right]) == 1, 'right atom should be terminal'
+            assert left != right, 'left and right atoms the same'
+            assert self.connected_components_count == 1, 'only single component structures supported'
+
+            seen = {right: 0}
+            queue = [(right, -10)]
+            while queue:
+                n, d = queue.pop(0)
+                for m in bonds[n].keys() - seen.keys():
+                    queue.append((m, d - 10))
+                    seen[m] = d
+            seen[left] = -1_000_000_000  # prioritize left atom
+
+            for _ in range(tries):
+                smiles, order = self._smiles(lambda x: seen[x] + random(), _return_order=True, random=True)
+                if order[-1] == right:
+                    break
+            else:
+                raise Exception('generation of smiles failed')
+            if remove_left:
+                smiles = smiles[2:]
+            if remove_right:
+                smiles = smiles[:-2]
+        else:
+            smiles = self._smiles(lambda x: x != left, random=True)
+            if remove_left:
+                smiles = smiles[2:]
+        return ''.join(smiles)
+
     def _smiles_order(self: 'MoleculeContainer', stereo=True) -> Callable:
         if stereo:
             return self._chiral_morgan.__getitem__
