@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2019-2021 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2019-2023 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  Copyright 2019 Tagir Akhmetshin <tagirshin@gmail.com>
 #  This file is part of chython.
 #
@@ -846,7 +846,7 @@ class Bk(Element, PeriodVII, GroupIII):
 
     @property
     def _valences_exceptions(self):
-        return (3, False, 0, ()), (4, False, 0, ()),
+        return (3, False, 0, ()), (4, False, 0, ())
 
     @property
     def atomic_radius(self):
