@@ -107,6 +107,10 @@ class Zr(Element, PeriodV, GroupIV):
                 (0, False, 0, ((1, 'Br'), (1, 'Br'))),
                 (0, False, 0, ((1, 'I'), (1, 'I'))),
                 (0, False, 0, ((1, 'H'), (1, 'H'))),
+                (0, False, 0, ((1, 'H'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'H'), (1, 'Br'))),
+                (0, False, 0, ((1, 'H'), (1, 'I'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'))),  # ZrCp2(CH3)2
 
                 (0, False, 0, ((1, 'F'), (1, 'F'), (1, 'F'))),
                 (0, False, 0, ((1, 'Cl'), (1, 'Cl'), (1, 'Cl'))),
